==> openid_connect_harid-8.x-1.0.tar.gz: openid_connect_harid/README.md <==
# HarID

A [HarID](https://harid.ee) client implementation for
[OpenID Connect](https://www.drupal.org/project/openid_connect) module.

Current implementation only provides a Single Sign-On (SSO) capability that
could mostly be achieved using the `Generic` client implementation. The main
difference is currently being predefined endpoints and custom scopes. Currently
used default scopes are `openid profile email roles`. If **Require strong session**
setting is enabled, then `session_type` is added to default scopes.

Additional capability is automated process for setting user language preference
based on value of `ui_locales` if one is present (the values are set upon each
successful authentication).

Enabling **strong session** requirement will not allow login for users that are not
logging in with ID-card or Mobile-ID for the current session. This makes sure that
there is a valid real person behind an account that authenticates.

A setting could control if test or live HarID is used, allowing the module to be
used for development and testing purposes.

# Usage

**NB! Please note that current codebase requires version 8.x-1.0-rc1.
Other versions could have different signatures for hook being used.**

1. Register your service with [HarID](https://harid.ee/en) using
[this](https://harid.ee/en/pages/dev-info) guide
  1. The callback redirect URL is SITE-BASE-URL/openid-connect/harid
1. Activate the module and enable the **HarID** client
  2. Client configuration and management is made in the admin section. You could
  use admin/config/services/openid-connect as a shortcut

# TODO

* Use `roles` scope to automatically manage additional local roles based on ones
provided by the Identity Provider.
* It might be a good idea to use `.well-known/openid-configuration` and
extract values from it directly instead of just having them hard-coded.

==> openid_connect_harid-8.x-1.2.tar.gz: openid_connect_harid/README.md <==
# HarID

A [HarID](https://harid.ee) client implementation for
[OpenID Connect](https://www.drupal.org/project/openid_connect) module.

Current implementation only provides a Single Sign-On (SSO) capability that
could mostly be achieved using the `Generic` client implementation. The main
difference is predefined endpoints and custom scopes. Default scopes are `openid profile email roles`.
If **Require strong session** setting is enabled, then `session_type` is added to default scopes.
If **require_personal_code** setting is enabled, then `personal_code` is added to default scopes.

Additional capability is automated process for setting user language preference
based on value of `ui_locales` if one is present (the values are set upon each
successful authentication).

Enabling **strong session** requirement will not allow login for users that are not
logging in with ID-card or Mobile-ID for the current session. This makes sure that
there is a valid real person behind an account that authenticates. Personal code is
a bit similar in nature, though it does not require strong session to be used for
current authentication, the IdP service just has to have that information available
(this most probably just requires strong session authentication to be used at least once).

A setting could control if test or live HarID is used, allowing the module to be
used for development and testing purposes.

# Usage

**NB! Please note that current codebase requires version 8.x-1.1.
Other versions could have different signatures for hook being used.**

1. Register your service with [HarID](https://harid.ee/en) using
[this](https://harid.ee/en/pages/dev-info) guide
  1. The callback redirect URL is SITE-BASE-URL/openid-connect/harid
1. Activate the module and enable the **HarID** client
  2. Client configuration and management is made in the admin section. You could
  use admin/config/services/openid-connect as a shortcut

# TODO

* Use `roles` scope to automatically manage additional local roles based on ones
provided by the Identity Provider.
* It might be a good idea to use `.well-known/openid-configuration` and
extract values from it directly instead of just having them hard-coded.
